@@ -203,11 +203,9 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         self.std_buttons_add(
             ('new', self.new_question),
             ('repeat', self.repeat_question),
-            ('give_up', self.give_up))
+            ('give_up', self.give_up),
+            ('backspace', self.on_backspace))
 
-        self.g_backspace = gu.bButton(self.action_area, _("_Backspace"),
-                     self.on_backspace)
-        self.g_backspace.set_sensitive(False)
         self.practise_box.show_all()
         ##############
         # config_box #
@@ -273,7 +271,6 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
         if self.g_rhythm_viewer.len() == len(self.m_t.m_question):
             if self.m_t.guess_answer(self.g_rhythm_viewer.m_data):
                 self.g_rhythm_viewer.happy_face()
-                self.g_backspace.set_sensitive(False)
                 self.std_buttons_answer_correct()
             else:
                 v = []
@@ -350,5 +347,4 @@ class Gui(abstract.Gui, abstract.RhythmAddOnGuiClass):
             self.g_rhythm_viewer.add_rhythm_element(i)
         self.m_t.q_status = self.QSTATUS_SOLVED
         self.std_buttons_give_up()
-        self.g_backspace.set_sensitive(False)
 
